Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
Server implements the api server. The api server is used to serve the rest api for kobs.
Directories
¶
| Path | Synopsis |
|---|---|
|
apis
|
|
|
clients
|
|
|
application/clientset/versioned
This package has the automatically generated clientset.
|
This package has the automatically generated clientset. |
|
application/clientset/versioned/fake
This package has the automatically generated fake clientset.
|
This package has the automatically generated fake clientset. |
|
application/clientset/versioned/scheme
This package contains the scheme of the automatically generated clientset.
|
This package contains the scheme of the automatically generated clientset. |
|
application/clientset/versioned/typed/application/v1beta1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
application/clientset/versioned/typed/application/v1beta1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
dashboard/clientset/versioned
This package has the automatically generated clientset.
|
This package has the automatically generated clientset. |
|
dashboard/clientset/versioned/fake
This package has the automatically generated fake clientset.
|
This package has the automatically generated fake clientset. |
|
dashboard/clientset/versioned/scheme
This package contains the scheme of the automatically generated clientset.
|
This package contains the scheme of the automatically generated clientset. |
|
dashboard/clientset/versioned/typed/dashboard/v1beta1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
dashboard/clientset/versioned/typed/dashboard/v1beta1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
team/clientset/versioned
This package has the automatically generated clientset.
|
This package has the automatically generated clientset. |
|
team/clientset/versioned/fake
This package has the automatically generated fake clientset.
|
This package has the automatically generated fake clientset. |
|
team/clientset/versioned/scheme
This package contains the scheme of the automatically generated clientset.
|
This package contains the scheme of the automatically generated clientset. |
|
team/clientset/versioned/typed/team/v1beta1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
team/clientset/versioned/typed/team/v1beta1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
cluster/terminal
Package terminal implements the functions for all terminal interactions in the frontend.
|
Package terminal implements the functions for all terminal interactions in the frontend. |
|
middleware
|
|
|
errresponse
Package errresponse implements a custom error renderer for the kobs api as it is described in the chi rest api example, which can be found here: https://github.com/go-chi/chi/blob/master/_examples/rest/main.go
|
Package errresponse implements a custom error renderer for the kobs api as it is described in the chi rest api example, which can be found here: https://github.com/go-chi/chi/blob/master/_examples/rest/main.go |
|
httplog
Package httplog implements our custom http logger for kobs based on logrus.
|
Package httplog implements our custom http logger for kobs based on logrus. |
|
plugins
|
|
Click to show internal directories.
Click to hide internal directories.